pub struct BoundedMailboxQueue { /* private fields */ }Trait Implementations
Sourceimpl Clone for BoundedMailboxQueue
impl Clone for BoundedMailboxQueue
Sourcefn clone(&self) -> BoundedMailboxQueue
fn clone(&self) -> BoundedMailboxQueue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoundedMailboxQueue
impl Debug for BoundedMailboxQueue
Sourceimpl QueueBase<MessageHandle> for BoundedMailboxQueue
impl QueueBase<MessageHandle> for BoundedMailboxQueue
Sourcefn len<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = QueueSize> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn len<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = QueueSize> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns the length of this queue.
このキューの長さを返します。 Read more
このキューの長さを返します。 Read more
Sourcefn capacity<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = QueueSize> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn capacity<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = QueueSize> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns the capacity of this queue.
このキューの最大容量を返します。 Read more
このキューの最大容量を返します。 Read more
Sourcefn is_empty<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn is_empty<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns whether this queue is empty.
このキューが空かどうかを返します。 Read more
このキューが空かどうかを返します。 Read more
Sourcefn non_empty<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn non_empty<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = bool> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Returns whether this queue is non-empty.
このキューが空でないかどうかを返します。 Read more
このキューが空でないかどうかを返します。 Read more
Sourceimpl QueueReader<MessageHandle> for BoundedMailboxQueue
impl QueueReader<MessageHandle> for BoundedMailboxQueue
Sourcefn poll<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<Option<MessageHandle>, QueueError<MessageHandle>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn poll<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<Option<MessageHandle>, QueueError<MessageHandle>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Retrieves and deletes the head of the queue. Returns None if the queue is empty.
キューの先頭を取得および削除します。キューが空の場合は None を返します。 Read more
キューの先頭を取得および削除します。キューが空の場合は None を返します。 Read more
fn clean_up<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourceimpl QueueWriter<MessageHandle> for BoundedMailboxQueue
impl QueueWriter<MessageHandle> for BoundedMailboxQueue
Sourcefn offer<'life0, 'async_trait>(
&'life0 mut self,
element: MessageHandle,
) -> Pin<Box<dyn Future<Output = Result<(), QueueError<MessageHandle>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn offer<'life0, 'async_trait>(
&'life0 mut self,
element: MessageHandle,
) -> Pin<Box<dyn Future<Output = Result<(), QueueError<MessageHandle>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
The specified element will be inserted into this queue,
if the queue can be executed immediately without violating the capacity limit.
容量制限に違反せずにすぐ実行できる場合は、指定された要素をこのキューに挿入します。 Read more
容量制限に違反せずにすぐ実行できる場合は、指定された要素をこのキューに挿入します。 Read more
Sourcefn offer_all<'life0, 'async_trait>(
&'life0 mut self,
elements: Vec<E>,
) -> Pin<Box<dyn Future<Output = Result<(), QueueError<E>>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
fn offer_all<'life0, 'async_trait>(
&'life0 mut self,
elements: Vec<E>,
) -> Pin<Box<dyn Future<Output = Result<(), QueueError<E>>> + Send + 'async_trait>>where
Self: Send + 'async_trait,
'life0: 'async_trait,
The specified elements will be inserted into this queue,
if the queue can be executed immediately without violating the capacity limit.
容量制限に違反せずにすぐ実行できる場合は、指定された複数の要素をこのキューに挿入します。 Read more
容量制限に違反せずにすぐ実行できる場合は、指定された複数の要素をこのキューに挿入します。 Read more